@@ -11,7 +11,7 @@
 #include <fcntl.h>
 #include <alsa/asoundlib.h>
 
-#define VERSION "0.3"
+#define VERSION "0.4"
 #define CHROOT_DIR "/var/empty"
 #define DEFAULT_SOUNDCARD "default"
 #define DEFAULT_CONTROL "Master"
@@ -101,8 +101,8 @@ static void usage()
 {
   puts(
 "pomavold V" VERSION " - POwerMAte VOLume Daemon\n\n"
-"usage: pomavold [-i <device>] [-s <soundcard>] [-c <control>] [-u <user>] "
-"[-d]\n"
+"usage: pomavold [-i <device>] [-s <soundcard>] [-c <control>] [-u <user>]\n"
+"                [-w <timeout>] [-d]\n"
 "       pomavold -h\n\n"
 "  -i <device>       use <device> as knob wheel; default:\n"
 "    " DEFAULT_DEVICE "\n"
@@ -111,6 +111,7 @@ DEFAULT_SOUNDCARD "\n"
 "  -c <control>      use <control> as volume control; default: "
 DEFAULT_CONTROL "\n"
 "  -u <user>         run as <user> and chroot to " CHROOT_DIR "\n"
+"  -w <timeout>      wait <timeout> seconds before accessing devices\n"
 "  -d                run in foreground, debug to stdout, don't log to "
 "syslog\n"
 "  -h                this help ;-)\n\n"
@@ -120,6 +121,7 @@ DEFAULT_CONTROL "\n"
 "to start automatically when the device is plugged in\n"
 "add the following to /etc/udev/rules.d/99-local.rules and\n"
 "do a `udevadm trigger`:\n\n"
+"  DEVPATH==\"/devices/*/usb*/input/input*/event*\",\\\n"
 "  ATTRS{product}==\"Griffin PowerMate\",\\\n"
 "  RUN=\"/usr/local/libexec/pomavold -u nobody -i %N\"\n"
 );
@@ -130,6 +132,7 @@ int main(int argc, char **argv)
   char *user = NULL;
   char *soundcard = DEFAULT_SOUNDCARD;
   char *control = DEFAULT_CONTROL;
+  int timeout = 0;
 
   snd_mixer_t *mixer;
   snd_mixer_selem_id_t *id;
@@ -152,7 +155,7 @@ int main(int argc, char **argv)
   int i;
 
   /* command line */
-  while ((i = getopt(argc, argv, "i:s:c:u:dh")) != -1) {
+  while ((i = getopt(argc, argv, "i:s:c:u:w:dh")) != -1) {
     switch (i) {
       case 'i':
         device = optarg;
@@ -166,6 +169,9 @@ int main(int argc, char **argv)
       case 'u':
         user = optarg;
         break;
+      case 'w':
+        timeout = atoi(optarg);
+        break;
       case 'd':
         debug = 1;
         break;
@@ -178,8 +184,26 @@ int main(int argc, char **argv)
     }
   }
 
-  if (!debug)
+  if (!debug) {
+    /* daemonize */
     openlog("pomavold", LOG_NDELAY | LOG_PID, LOG_DAEMON);
+    pid = fork();
+    if (pid < 0) ERR("fork()");
+    if (pid > 0) return 0;
+
+    if (chdir("/") < 0) ERR("chdir() to / failed");
+    if (setsid() < 0) ERR("setsid()");
+  }
+
+  /* wait for devices to appear */
+  if (timeout > 0) {
+    if (debug)
+      printf("sleeping for %i seconds\n", timeout);
+    else
+      syslog(LOG_INFO, "sleeping for %i seconds\n", timeout);
+
+    sleep(timeout);
+  }
 
   /* open mixer */
   if ((i = snd_mixer_open(&mixer, 0)))
@@ -222,16 +246,6 @@ int main(int argc, char **argv)
     if (!pw) ERRX("no such user: %s", user);
   }
 
-  if (!debug) {
-    /* daemonize */
-    pid = fork();
-    if (pid < 0) ERR("fork()");
-    if (pid > 0) return 0;
-
-    if (chdir("/") < 0) ERR("chdir() to / failed");
-    if (setsid() < 0) ERR("setsid()");
-  }
-
   if (user) {
     /* drop privileges, chroot */
     if (initgroups(user, pw->pw_gid) < 0) ERR("initgroups()");
@@ -356,7 +370,8 @@ int main(int argc, char **argv)
                                                 active);
         if (i) WARNS("snd_mixer_selem_set_playback_switch()");
 
-        if (debug) printf("pressed: active=%i\n", active);
+        if (debug)
+          printf("pressed: active=%i\n", active);
 
         set_brightness(active);
       }
